%define oversion %(echo %{version} | tr . -)

Name:           fizmo
Summary:        A Z-Machine interpreter supporting unicode, sound, blorbfile and more
Version:        0.8.2
Release:        %mkrel 6
License:        BSD
Group:          Games/Adventure
URL:            https://fizmo.spellbreaker.org
Source0:        https://github.com/chrender/fizmo/releases/download/%{name}_%{oversion}/%{name}-%{version}.tar.gz

BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(x11)
BuildRequires:  xsltproc

# TODO: Package and unbundle Fira Sans and Fira Mono fonts

%description
Fizmo is a Z-Machine interpreter. That means it allows you to play interactive
fiction, also know as text adventures, which were implemented either by Infocom
or created using the Inform compiler. It is a console-based interpreter,
meaning that there is no graphical user interface, and works with all Z-machine
versions except version 6.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -std=gnu17"
%configure prefix=%{_prefix} bindir=%{_gamesbindir}
%make_build

# generate docs
cd doc
sh create-txts.sh

%install
%make_install

cd %{buildroot}%{_gamesbindir}
ln -s fizmo-ncursesw fizmo
cd %{buildroot}%{_mandir}/man6/
ln -s fizmo-ncursesw.6.xz fizmo.6.xz

%files
%doc CHANGELOG.txt COPYRIGHT.txt QUICKSTART.txt README.txt user-config-example.txt
%{_mandir}/man6/%{name}*
%{_gamesbindir}/%{name}
%{_gamesbindir}/%{name}-console
%{_gamesbindir}/%{name}-ncursesw
%{_gamesbindir}/%{name}-sdl2
%dir %{_datadir}/%{name}
# TODO: Unbundle!
%{_datadir}/%{name}/fonts/
%lang(de) %{_datadir}/%{name}/locales/de_DE/*
%lang(en) %{_datadir}/%{name}/locales/en_US/*
%lang(fr) %{_datadir}/%{name}/locales/fr_FR/*


%changelog
* Tue May 13 2025 ns80 <ns80> 0.8.2-6.mga10
+ Revision: 2183168
- try to fix building with GCC 15

* Sun Mar 16 2025 wally <wally> 0.8.2-5.mga10
+ Revision: 2164783
- rebuild for libxml2 2.13.6

* Fri Apr 01 2022 umeabot <umeabot> 0.8.2-4.mga9
+ Revision: 1838766
- Mageia 9 Mass Rebuild

* Thu Feb 13 2020 umeabot <umeabot> 0.8.2-3.mga8
+ Revision: 1512310
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0.8.2-2.mga7
+ Revision: 1297709
- Mageia 7 Mass Rebuild

* Sun Jan 01 2017 akien <akien> 0.8.2-1.mga6
+ Revision: 1079336
- Version 0.8.2
- New SDL2 frontend
- Fira fonts are bundled, should be unbundled asap

* Sun Jan 17 2016 daviddavid <daviddavid> 0.7.9-4.mga6
+ Revision: 925155
- switch to %%configure2_5x to fix build

* Wed Oct 15 2014 umeabot <umeabot> 0.7.9-3.mga5
+ Revision: 746299
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.9-2.mga5
+ Revision: 679218
- Mageia 5 Mass Rebuild

* Tue Aug 12 2014 stormi <stormi> 0.7.9-1.mga5
+ Revision: 662068
- update to fizmo 0.7.9

* Sat Oct 19 2013 umeabot <umeabot> 0.7.7-2.mga4
+ Revision: 533143
- Mageia 4 Mass Rebuild

* Mon Aug 26 2013 stormi <stormi> 0.7.7-1.mga4
+ Revision: 471864
- new version 0.7.7
- now uses standard build macros

* Mon Jun 03 2013 fwang <fwang> 0.7.6-3.mga4
+ Revision: 435852
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 0.7.6-2.mga3
+ Revision: 350462
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ malo <malo>
- fix RPM group

* Thu Jan 03 2013 akien <akien> 0.7.6-1.mga3
+ Revision: 338309
- Update to fizmo 0.7.6. Adaptation to automake/autoconfig system, see CHANGELOG for a comprehensive list.

* Thu Aug 02 2012 stormi <stormi> 0.7.3-1.mga3
+ Revision: 277834
- new version 0.7.3

* Sun Mar 18 2012 stormi <stormi> 0.7.2-1.mga2
+ Revision: 223824
- update to 0.7.2 final

* Mon Mar 05 2012 stormi <stormi> 0.7.2-0.beta.1.mga2
+ Revision: 219285
- 0.7.2 beta

* Thu Jun 30 2011 stormi <stormi> 0.6.10-1.mga2
+ Revision: 116890
- new bugfix release 0.6.10

* Wed May 04 2011 stormi <stormi> 0.6.9-1.mga1
+ Revision: 94935
- new bugfix version 0.6.9

* Sat Mar 26 2011 stormi <stormi> 0.6.8-3.mga1
+ Revision: 77713
+ rebuild (emptylog)

* Sat Jan 08 2011 stormi <stormi> 0.6.8-2.mga1
+ Revision: 861
- imported package fizmo


* Sun Dec 05 2010 Oden Eriksson <oeriksson@mandriva.com> 0.6.8-2mdv2011.0
+ Revision: 610429
- rebuild

* Tue Jan 12 2010 Samuel Verschelde <stormi@mandriva.org> 0.6.8-1mdv2010.1
+ Revision: 490460
- update to new version 0.6.8

* Tue Dec 15 2009 Samuel Verschelde <stormi@mandriva.org> 0.6.7-1mdv2010.1
+ Revision: 479047
- new version 0.6.7

* Tue Oct 13 2009 Samuel Verschelde <stormi@mandriva.org> 0.6.5-1mdv2010.0
+ Revision: 457189
- new version 0.6.5

* Fri May 29 2009 Samuel Verschelde <stormi@mandriva.org> 0.6.4-1mdv2010.0
+ Revision: 381111
- new version 0.6.4
- drop merged upstream patches

* Thu May 21 2009 Samuel Verschelde <stormi@mandriva.org> 0.6.3-2mdv2010.0
+ Revision: 378314
- fix a typo in package description

* Wed May 20 2009 Samuel Verschelde <stormi@mandriva.org> 0.6.3-1mdv2010.0
+ Revision: 378095
- upstream patches to fix crash and graphical glitches
- import fizmo


